﻿using Microsoft.AspNetCore.Mvc;
using ELTE.TodoList.Web.Models;
using ELTE.TodoList.Web.Services;

namespace ELTE.TodoList.Web.Controllers
{
    public enum SortOrder { NAME_DESC, NAME_ASC, DEADLINE_DESC, DEADLINE_ASC }

    public class ListsController : Controller
    {
        private readonly ITodoListService _service;

        public ListsController(ITodoListService service)
        {
            _service = service;
        }

        // GET: Lists
        public IActionResult Index()
        {
            return View(_service.GetLists());
        }

        // GET: Lists/Details/5
        public IActionResult Details(int id, SortOrder sortOrder = SortOrder.NAME_ASC)
        {
            try
            {
                ViewData["NameSortParam"] = sortOrder == SortOrder.NAME_DESC ? SortOrder.NAME_ASC : SortOrder.NAME_DESC;
                ViewData["DeadLineSortParam"] = sortOrder == SortOrder.DEADLINE_DESC ? SortOrder.DEADLINE_ASC : SortOrder.DEADLINE_DESC;

                List list = _service.GetListDetails(id);

                switch (sortOrder)
                {
                    case SortOrder.NAME_DESC:
                        list.Items = list.Items.OrderByDescending(i => i.Name).ToList();
                        break;
                    case SortOrder.NAME_ASC:
                        list.Items = list.Items.OrderBy(i => i.Name).ToList();
                        break;
                    case SortOrder.DEADLINE_DESC:
                        list.Items = list.Items.OrderByDescending(i => i.Deadline).ToList();
                        break;
                    case SortOrder.DEADLINE_ASC:
                        list.Items = list.Items.OrderBy(i => i.Deadline).ToList();
                        break;
                    default:
                        break;
                }

                return View(list);
            }
            catch (InvalidOperationException)
            {
                return NotFound();
            }
        }
    }
}
